#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <iconv.h>


typedef struct ITEXT{
	unsigned int c1;
	unsigned int c2;

	char *utf8;

	int x_off;
	int y_off;

	int ej;
	int chu;
	int bouten;
	int small;

	struct ITEXT *rubi_head;
	struct ITEXT *rubi_tail;

	struct ITEXT *chu_head;
	struct ITEXT *chu_tail;

	struct ITEXT *next;
	struct ITEXT *prev;
}ITEXT_T;
typedef struct IBUF{
	unsigned char *buf;
	int line;

	ITEXT_T *i_head;
	ITEXT_T *i_tail;
	
	struct IBUF *next;
	struct IBUF *prev;
}IBUF_T;
typedef struct BOOKFILEDATA{
        char fullpath[256];
        char filename[256];
        char title[256];
        int size;
        int code;

        struct BOOKFILEDATA *next;
        struct BOOKFILEDATA *prev;
}IBOOK_T;

int ibookGetFileData(IBOOK_T **,IBOOK_T **,char *);

void book_link_free(IBOOK_T **,IBOOK_T **);

int itextGetTextData(char *,char *,IBUF_T **,IBUF_T **,int);

int _checkFileType(char *);

int itextUnZipFile(char *,char *);

char * euc2utf8(iconv_t,char *,int);

